@@ -16,6 +16,8 @@ from datetime import timedelta
 import os
 import os.path
 import copy
+from cartopy.img_transform import mesh_projection, regrid
+from cartopy.crs import PlateCarree
 
 import logging
 
@@ -58,37 +60,30 @@ def do_interpolation(data, lon, lat):
     """ Takes a not regular grid (curvilinear, whatever kind) and interpolate
     to regular one derived from the first. Very demanding operation, try to
     avoid """
-    # lon as second dimension
-    # lat as first dimension
     LOG.info("Irregular grid, performing interpolation ...")
-    lat_s = lat.shape[0]
-    lon_s = lon.shape[1]
-    reglon = np.linspace(lon.min(), lon.max(), lon_s)
-    reglat = np.linspace(lat.min(), lat.max(), lat_s)
-    LOG.info("LAT: %s, LON: %s, DATA: %s", reglon.shape, reglat.shape,
-             data.shape)
-    regx, regy = np.meshgrid(reglon, reglat)
-    result = np.empty(data.shape)*np.nan
-    if ma.is_masked(data):
-        data = data.filled(np.nan)
+    projection = PlateCarree()
+    new_lon, new_lat, _ = mesh_projection(
+        projection, data.shape[-1], data.shape[-2],
+        # x_extents=(lon.min(), lon.max()),
+        # y_extents=(lat.min(), lat.max())
+    )
 
+    def _interpolate(to_regrid):
+        return  regrid(to_regrid, lon, lat, projection, projection, new_lon, new_lat)
+        
+    result = np.empty_like(data)
+    result.fill(np.nan)
     # assuming that lat and lon are the latest dimensions
     if len(data.shape) == 2:
-        result = griddata((lon.ravel(), lat.ravel()), data.ravel(), (regx,
-                                                                     regy))
+        result = _interpolate(data)
     elif len(data.shape) == 3:
         for i in range(data.shape[0]):
-            tmp = griddata((lon.ravel(), lat.ravel()), data[i].ravel(), (regx,
-                                                                         regy))
-            result[i] = tmp.reshape(result[i].shape)
+            result[i, :, :] = _interpolate(data[i])
     elif len(data.shape) == 4:
         for i in range(data.shape[0]):
             for j in range(data.shape[1]):
-                tmp = griddata((lon.ravel(), lat.ravel()), data[i, j].ravel(),
-                               (regx, regy))
-                result[i, j, :, :] = tmp.reshape(result[i, j, :, :].shape)
-    # elif len(data.shape) == 5:
-    return np.ma.masked_where(np.isnan(result), result), regx, regy
+                result[i, j, :, :] = _interpolate(data[i, j])
+    return result, new_lon[0], new_lat[:, 0]
 
 
 def extract_coords(self, var, coord='lons'):
@@ -127,7 +122,7 @@ def parse_parameters_list(plist):
         if len(plist) == 1:
             plist = plist[0]
         else:
-            return list(plist)
+            return [float(val) for val in plist]
     if str(plist).find('-') > 0:
         tmp = plist.strip('[]')
         try:
@@ -715,6 +710,7 @@ class MapGenerator(object):
         self.orig_projection_kwargs = kwargs.get('orig_projection_kwargs', dict())
         self.projection     = kwargs.get('projection', 'PlateCarree')
         self.projection_kwargs = kwargs.get('projection_kwargs', dict())
+        self.extent         = kwargs.get('extent', 'auto')
         self.subsetting     = kwargs.get('subsetting', True)
         self.dimension      = kwargs.get('dimension', None)
         self.continents     = kwargs.get('continents', None)
@@ -740,9 +736,9 @@ class MapGenerator(object):
         if cube.attributes.get('plot_name', None):
             show_name = cube.attributes['plot_name']
         elif cube.long_name and len(cube.long_name) < 45:
-            show_name = cube.long_name
+            show_name = f"{cube.long_name} ({cube.var_name})"
         elif cube.standard_name and len(cube.standard_name) < 45:
-            show_name = cube.standard_name
+            show_name = f"{cube.standard_name} ({cube.var_name})"
         else:
             show_name = cube.var_name
         return f"{show_name} ({cube.units})"
@@ -770,6 +766,7 @@ class MapCross(MapGenerator):
         self.contours_int   = kwargs.get('contours_int', 1)
         self.smooth         = kwargs.get('smooth', False)
         self.colorbar       = kwargs.get('colorbar', True)
+        self.colorbar_location = kwargs.get('colorbar_location', 'right')
         self.formats        = kwargs.get('formats', None)
         self.noruntime      = kwargs.get('noruntime', False)
         self.timesteps      = kwargs.get('timesteps', '0')
