@@ -18,7 +18,7 @@ import numpy as np
 from datetime import datetime
 import os.path
 import subprocess
-from collections import Iterable
+from collections.abc import Iterable
 from PIL import Image
 from .definitions import MapData
 from .definitions import MapCross
@@ -760,7 +760,7 @@ class PlotMap(MapCross, MapDrawOptions):
                                       frame_on=True)
             self.mgplot = plt.gcf()
         self.mgaxis.patch.set_edgecolor('black')
-        self.mgaxis.patch.set_linewidth('1')
+        self.mgaxis.patch.set_linewidth(1)
         self.gen_image_map(
             fig_name,
             grid,
